# Introduction

This module provides server-side tracking of pages in Google Analytics using [Google Analytics Measurement Protocol][info]. This is useful when it is not possible to access traditional Javascript-based Google Analytics. It can track some pages out of the box, and also enables use of its helper methods which can be invoked from custom code.


# Installation

It is recommended to use Composer to add the module and its dependencies to the project (`composer require drupal/management_protocol`), and to install the module using Drush (`drush pm:enable management_protocol`) or via the Back-office. More information on Drupal module installation at https://www.drupal.org/node/1897420.


# Requirements

This module requires:
* Drupal module [Google Analytics][GA module]
* PHP library [Google Analytics Measurement Protocol][library]


# Configuration

The tracked pages can be configured at Administration » Configuration » System » Google Analytics » Measurement protocol.
For each of supported cases, one can:
* Enable or disable the tracking
* Choose which type of Google analytics hit is more suitable: a page visit or an event.


# Usage

Certain Drupal pages can't be tracked the regular way in Google Analytics, because browser context (with Javascript) is not available.
Some of such cases are:
* Private file downloads - if the download link is received in an email or a messaging app.
* User-related callbacks which immediately redirect to another page, for example using of one-time password reset links.

This module covers these two scenarios out of the box.

## Using the PHP helpers

The module provides a service with public methods, so tracking can be invoked programmatically from custom code, like this:
```
use Drupal\measurement_protocol\Tracker;

\Drupal::service('measurement_protocol.tracker')->track(Tracker::HIT_TYPE_PAGE, [
  'path' => $url,
  'title' => $title,
  'referrer' => $previous_url,
]);

\Drupal::service('measurement_protocol.tracker')->track(Tracker::HIT_TYPE_EVENT, [
  'category' => 'document',
  'action' => 'download',
  'id' => $file->id(),
  'label' => $file->getFilename(),
]);
```
For more information on what data you can send, see [this reference][reference] and the [library] reference.
The rest of the hit types are not implemented, but could be implemented very easily. Patches accepted.

[info]: https://developers.google.com/analytics/devguides/collection/protocol/v1/
[reference]: https://developers.google.com/analytics/devguides/collection/protocol/v1/reference
[GA module]: https://www.drupal.org/project/google_analytics
[library]: https://github.com/theiconic/php-ga-measurement-protocol