<?php

namespace Drupal\measurement_protocol;

use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Manages tracking of user-related pages.
 */
class UserTracker {

  /**
   * The Google measurement protocol tracker service.
   *
   * @var \Drupal\measurement_protocol\Tracker
   */
  protected $tracker;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Class constructor.
   *
   * @param \Drupal\measurement_protocol\Tracker $tracker
   *   The Google measurement protocol tracker service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   */
  public function __construct(Tracker $tracker,
                              ConfigFactoryInterface $config_factory) {
    $this->tracker = $tracker;
    $this->configFactory = $config_factory;
  }

  /**
   * Prepare info about user password reset and send to Google Analytics.
   *
   * @param string $uri
   *   Relative URI of page.
   * @param bool $success
   *   Whether there was an error using the one-time link.
   * @param string[] $parameters
   *   Parameters to the password reset route.
   */
  public function trackUserPasswordReset($uri, $success, array $parameters) {
    $settings = $this->configFactory->get('measurement_protocol.settings');
    if (!$settings->get('user_password_reset.enabled')) {
      return;
    }
    // Prepare all data related to the visit to one-time passoword reset link.
    switch ($hit_type = $this->tracker->getHitType('user_password_reset')) {
      case Tracker::HIT_TYPE_PAGEVIEW:
        $data = [
          // @todo check if it is safe to track full URL in GA,
          // for security reasons. The URL should be "garbled".
          'path' => $uri,
          'title' => 'Reset password',
        ];
        break;

      case Tracker::HIT_TYPE_EVENT:
        $data = [
          'category' => 'user',
          'action' => 'password_reset',
          'id' => $parameters['uid'],
          'label' => $success ? 'Success' : 'Failure',
        ];
        break;
    }
    // @todo add a hook to allow modules to alter sent data.
    // Send data to Google Analytics:
    $this->tracker->track($hit_type, $data);

  }

}
